==> knapster-0.9.tar.gz: knapster-0.9/knapster/consolepanel.h <==
/***************************************************************************
                          consolepanel.h  -  description
                             -------------------
    begin                : Sat Jan 15 2000
    copyright            : (C) 2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSOLEPANEL_H
#define CONSOLEPANEL_H

#include <qwidget.h>
#include <qmultilinedit.h>
#include <qlineedit.h>

class ExtLineEdit;

/**the console/command panel for
knapster
  *@author John Donoghue
  */

class QPixmap;

class ConsolePanel : public QWidget  {
   Q_OBJECT
signals:
  // signal for return pressed in thye search text box
  void command(const char *);
public slots:
  void clear();
private slots:
  // internal slots
  void calcCommand();
public: 
	ConsolePanel(QWidget *parent=0, const char *name=0);
	virtual ~ConsolePanel();

  void writeString(QString s);
private:
  QMultiLineEdit *consolewin;
  ExtLineEdit *commandwin;
//  QPixmap *logo; // the logo shown up the top right
};

#endif

==> knapster-0.12.tar.gz: knapster-0.12/knapster/consolepanel.h <==
/***************************************************************************
                          consolepanel.h  -  description
                             -------------------
    begin                : Sat Jan 15 2000
    copyright            : (C) 2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSOLEPANEL_H
#define CONSOLEPANEL_H

#include <qwidget.h>
#include <qmultilinedit.h>
#include <qlineedit.h>

#include "extlistbox.h"

class ExtLineEdit;

/**the console/command panel for
knapster
  *@author John Donoghue
  */

class QPixmap;

class ConsolePanel : public QWidget  {
   Q_OBJECT
signals:
  // signal for return pressed in thye search text box
  void command(const char *);
public slots:
  void clear();
private slots:
  // internal slots
  void calcCommand();
public: 
	ConsolePanel(QWidget *parent=0, const char *name=0);
	virtual ~ConsolePanel();

  void writeString(QString s,ExtListBox::LineType type);

  void setColors(
    const QColor &norm,const QColor &info,const QColor &msg,
    const QColor &err);

private:
//  QMultiLineEdit *consolewin;
  ExtListBox *consolewin;

  ExtLineEdit *commandwin;
//  QPixmap *logo; // the logo shown up the top right
};

#endif
